<?php

/******************************************************************************/
/******************************************************************************/

class ThemePage
{
	/**************************************************************************/

	function __construct()
	{

	}
	
	/**************************************************************************/
	
	function adminInitMetaBox()
	{
		add_meta_box('meta_box_page',__('Page options',THEME_DOMAIN),array($this,'adminCreateMetaBoxPage'),'page','normal','low');	
	}
	
	/**************************************************************************/

	function adminCreateMetaBoxPage() 
	{
		global $post;
		
		$data=array();
	
		$data['option']=ThemeOption::getPostMeta($post);
		
		$data['dictionary']['postCategory']=ThemeHelper::createTermDictionary('category',array(),array(),array(),'id');
		
		$Template=new ThemeTemplate($data,THEME_PATH_TEMPLATE.'admin/meta_box_page.php');
		echo $Template->output();	
	}
	
	/**************************************************************************/
	
	function getImageClass($sidebar)
	{
		if($sidebar==0) return('image-1180');
		else return('image-960');
	}
		
	/**************************************************************************/
	
	function displayHeader()
	{
		$html=null;
		
		global $norgeParentPost;
		
		$Post=new ThemePost();
		$Validation=new ThemeValidation();
		
		$meta=ThemeOption::getPostMeta($norgeParentPost->post);
		
		$headerMetaEnable=$Post->getPost()===false ? true : false;

		if(ThemeOption::getGlobalOption($norgeParentPost->post,'content_header_enable') && (!is_home()))
		{
			$postType=get_post_type($norgeParentPost->post);
			
			$html=
			'
				<div class="theme-content-header">
					<div class="pb-header aligncenter">
			';

			if(in_array($postType,array('page')))
			{
				if($Validation->isNotEmpty($meta['subheader']))
					$html.='<h6>'.esc_html($meta['subheader']).'</h6>';
				if($Validation->isNotEmpty($meta['header']) && ($headerMetaEnable))
					$html.='<h1>'.$meta['header'].'</h1>';		
				else $headerMetaEnable=false;
			}
			elseif(in_array($postType,array('post')))
			{
				$headerMetaEnable=false;
				
				if(ThemeOption::getGlobalOption($norgeParentPost->post,'post_date_visible'))
				{
					$html.=
					'
						<div class="theme-circle theme-circle-size-large">
							<span class="theme-circle-top">
								<a href="'.esc_url(get_month_link(get_the_time('Y',$norgeParentPost->post->ID),get_the_time('m',$norgeParentPost->post->ID))).'" title="'.sprintf(esc_attr__('View all posts from "%s %s".',THEME_DOMAIN),get_the_time('F',$norgeParentPost->post->ID),get_the_time('Y',$norgeParentPost->post->ID)).'">
									'.esc_html(get_the_date(get_option('date_format'),$norgeParentPost->post->ID)).'
								</a>
							</span>
						</div>
						<div class="pb-header-underline"></div>
					';
				}
			}
			
			if(!$headerMetaEnable)
			{
				$html.=
				'
					<h1>'.esc_html($norgeParentPost->post->post_title).'</h1>
				';
			}
			
			if(in_array($postType,array('page')))
			{
				$html.=
				'
					<div class="pb-header-underline"></div>
				';				
			}
			elseif(in_array($postType,array('post')))
			{
				$b=array();
				
				$b[0]=ThemeOption::getGlobalOption($norgeParentPost->post,'post_category_visible');
				$b[1]=ThemeOption::getGlobalOption($norgeParentPost->post,'post_author_name_visible');
				$b[2]=ThemeOption::getGlobalOption($norgeParentPost->post,'post_tag_visible');
				
				if(in_array(true,$b))
				{
					$html.=
					'
						<div class="theme-content-header-meta">
					';
					
					if($b[0])
					{
						$category=$Post->createCategoryList();
						if($Validation->isNotEmpty($category))
							$html.='<div>'.sprintf(esc_html__('In %s',THEME_DOMAIN),$category).'</div>';					
					}
					if($b[1])
					{
						$authorName=get_the_author_meta('display_name',$norgeParentPost->post->post_author);
						$author='<a href="'.esc_url(get_author_posts_url($norgeParentPost->post->post_author)).'" title="'.sprintf(esc_attr('View all posts from "%s".',THEME_DOMAIN),$authorName).'">'.esc_html($authorName).'</a>';
						if($Validation->isNotEmpty($author))
							$html.='<div>'.sprintf(esc_html__('By %s',THEME_DOMAIN),$author).'</div>';						
					}
					if($b[2])
					{
						$tag=$Post->createTagList();
						if($Validation->isNotEmpty($tag))
							$html.='<div>'.sprintf(esc_html__('Tags: %s',THEME_DOMAIN),$tag).'</div>';					
					}
					
					$html.=
					'
						</div>
					';
				}
			}
			
			$html.=
			'
					</div>
				</div>
			';
		}
		
		return($html);
	}
	
	/**************************************************************************/
	
	function getPageDictionary($useNone=true,$useGlobal=true,$useLeftUnchaged=false)
	{
		$data=array();
		
		$page=get_pages(array('hierarchical'=>0));
		
		if($useNone) $data[0]=array(__('[None]',THEME_DOMAIN));
		if($useGlobal) $data[-1]=array(__('[Use global settings]',THEME_DOMAIN));
		if($useLeftUnchaged) $data[-10]=array(__('[Left unchanged]',THEME_DOMAIN));

		foreach($page as $pageData)
			$data[$pageData->ID]=array($pageData->post_title);
		
		return($data);
	}
	
	/**************************************************************************/
	
	function displayTitle($title)
	{
		$Validation=new ThemeValidation();
		
		global $norgeParentPost;
		
		$title=get_bloginfo('name');
		
		if((!$Validation->isEmpty($title)) && (is_object($norgeParentPost->post))) 
			$title.=' | '.$norgeParentPost->post->post_title;

		return($title);
	}
	
	/**************************************************************************/
	
	function getCurrentTemplate()
	{
		global $norgeParentPost;
		return(get_post_meta($norgeParentPost->post->ID,'_wp_page_template',true));
	}
	
	/**************************************************************************/
	
	function setPostMetaDefault(&$meta,$part='all')
	{
		if(in_array($part,array('page','all')))
		{
			ThemeHelper::setDefaultOption($meta,'post_category',array());
			ThemeHelper::setDefaultOption($meta,'header','');
			ThemeHelper::setDefaultOption($meta,'subheader','');
		}
	}
	
	/**************************************************************************/
}

/******************************************************************************/
/******************************************************************************/