<?php

/******************************************************************************/
/******************************************************************************/

class ThemePost
{
	/**************************************************************************/
	
	function __construct()
	{
		$this->videoType=array
		(
			'vimeo'																=>	array(__('Vimeo video',THEME_DOMAIN)),
			'youtube'															=>	array(__('Youtube video',THEME_DOMAIN)),
			'metacafe'															=>	array(__('Metacafe video',THEME_DOMAIN)),
			'dailymotion'														=>	array(__('Dailymotion video',THEME_DOMAIN))
		);	
	}
	
	/**************************************************************************/
	
	function adminInitMetaBox()
	{
		add_meta_box('meta_box_post',__('Post Options',THEME_DOMAIN),array($this,'adminCreateMetaBoxPost'),'post','normal','low');	
		add_meta_box('meta_box_post_audio',__('Post Type: Audio',THEME_DOMAIN),array($this,'adminCreateMetaBoxPostAudio'),'post','normal','low');	
		add_meta_box('meta_box_post_video',__('Post Type: Video',THEME_DOMAIN),array($this,'adminCreateMetaBoxPostVideo'),'post','normal','low');
		add_meta_box('meta_box_post_gallery',__('Post Type: Gallery',THEME_DOMAIN),array($this,'adminCreateMetaBoxPostGallery'),'post','normal','low');	
	}
	
	/**************************************************************************/
	
	function adminCreateMetaBoxPost() 
	{
		global $post;
		
		$data=array();
	
		$data['option']=ThemeOption::getPostMeta($post);	
		
		$this->setPostMetaDefault($data['option'],'post');
		
		$Template=new ThemeTemplate($data,THEME_PATH_TEMPLATE.'admin/meta_box_post.php');
		echo $Template->output();	
	}
	
	/**************************************************************************/
	
	function adminCreateMetaBoxPostAudio() 
	{
		global $post;
		
		$data=array();
	
		$data['option']=ThemeOption::getPostMeta($post);	
		
		$this->setPostMetaDefault($data['option'],'post_audio');
	
		$Template=new ThemeTemplate($data,THEME_PATH_TEMPLATE.'admin/meta_box_post_audio.php');
		echo $Template->output();			
	}
	
	/**************************************************************************/
	
	function adminCreateMetaBoxPostVideo() 
	{
		global $post;
		
		$data=array();
	
		$data['option']=ThemeOption::getPostMeta($post);	
		
		$data['dictionary']['videoType']=$this->videoType;
		
		$this->setPostMetaDefault($data['option'],'post_video');
		
		$Template=new ThemeTemplate($data,THEME_PATH_TEMPLATE.'admin/meta_box_post_video.php');
		echo $Template->output();			
	}
	
	/**************************************************************************/
	
	function adminCreateMetaBoxPostGallery() 
	{
		global $post;
		
		$data=array();
	
		$data['option']=ThemeOption::getPostMeta($post);	
		
		$this->setPostMetaDefault($data['option'],'post_gallery');
		
		$Template=new ThemeTemplate($data,THEME_PATH_TEMPLATE.'admin/meta_box_post_gallery.php');
		echo $Template->output();			
	}

	/**************************************************************************/
	
	function getPost()
	{
		$data=new stdClass();

		$categoryId=(int)get_query_var('cat');

		if(is_tag()) 
		{
			$data->post=get_post(ThemeOption::getOption('blog_search_post_id'));
			
			$tagQuery=get_query_var('tag');
			$tagData=get_tags(array('slug'=>$tagQuery));

			$data->post->post_title=$tagData[0]->name;
		}
		elseif(is_author())
		{
			$author=get_userdata(get_query_var('author'));
			$data->post=get_post(ThemeOption::getOption('blog_author_post_id'));
			$data->post->post_title=sprintf(__('All posts from %s',THEME_DOMAIN),get_the_author_meta('display_name',$author->data->ID));			
		}
		elseif(is_category($categoryId)) 
		{			
			$category=get_category($categoryId);
			$data->post=get_post(ThemeOption::getOption('blog_category_post_id'));	
			$data->post->post_title=esc_html($category->name);	
		}
		elseif(is_day()) 
		{
			$data->post=get_post(ThemeOption::getOption('blog_archive_post_id'));
			$data->post->post_title=get_the_date();
		}
		elseif(is_archive()) 
		{
			$data->post=get_post(ThemeOption::getOption('blog_archive_post_id'));
			$data->post->post_title=single_month_title(' ',false);
		}
		elseif(is_search())
		{
			$data->post=get_post(ThemeOption::getOption('blog_search_post_id'));
			$data->post->post_title=sprintf(__('Search result for phrase %s',THEME_DOMAIN),get_query_var('s'));
		}
		elseif(is_404())
		{
			$data->post=get_post(ThemeOption::getOption('page_404_page_id'));
			$data->post->post_title=$data->post->post_title;
		}
		else return(false);

		return($data);
	}
	
	/**************************************************************************/
	
	function createTagList()
	{	
		$i=0;
		$html=null;
		
		$tag=get_the_tags();
						
		if(!$tag) return($html); 
		
		$count=count($tag);
		
		foreach($tag as $value)
		{
			$i++;

			$html.=
			'
				<li><a href="'.esc_url(get_tag_link($value->term_id)).'" title="'.sprintf(esc_attr__('View all posts marked as "%s".',THEME_DOMAIN),$value->name).'">'.esc_html($value->name).'</a>'.($i==$count ? '' : ',&nbsp;').'</li>
			';
		}
		
		$html=
		'	
			<ul class="theme-reset-list">
				'.$html.'
			</ul>
		';
		
		return($html);
		
	}
	
	/**************************************************************************/
	
	function createCategoryList()
	{
		$html=null;
		
		$Validation=new ThemeValidation();
		
		$category=get_the_category(get_the_ID());
		$count=count($category);
						
		if(!$count) return($html);
	
		$i=0;
		foreach($category as $index=>$value)
		{
			if($value->term_id==1) continue;
			
			$title=$Validation->isEmpty($value->description) ? sprintf(__('View all posts filed under "%s".',THEME_DOMAIN),$value->name) : strip_tags(apply_filters('category_description',$value->description,$value));
			
			$html.=
			'
				<li><a href="'.esc_url(get_category_link($value->term_id)).'" title="'.esc_attr($title).'">'.esc_html($value->name).'</a>'.($i==$count-1 ? '' : ',&nbsp;').'</li>
			';
			
			$i++;
		}
		
		if($Validation->isNotEmpty($html))
		{
			$html=
			'
				<ul class="theme-reset-list">
					'.$html.'
				</ul>
			';
		}
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createPostNavigation()
	{
		$html=null;
		$counter=0;
		$Validation=new ThemeValidation();
		
		$prevPost=get_previous_post();
		if(!empty($prevPost)) 
		{
			$counter++;
			$html.='<a class="theme-post-navigation-prev" href="'.esc_url(get_permalink($prevPost->ID)).'" title="'.the_title_attribute(array('post'=>$prevPost->ID,'echo'=>false)).'"><span class="theme-post-navigation-label">'.esc_html__('Prev:',THEME_DOMAIN).'</span><span class="theme-post-navigation-title">'.esc_html(get_the_title($prevPost->ID)).'</span></a>';
		}
		
		$nextPost=get_next_post();
		if(!empty($nextPost)) 
		{
			$counter++;
			$html.='<a class="theme-post-navigation-next" href="'.esc_url(get_permalink($nextPost->ID)).'" title="'.the_title_attribute(array('post'=>$nextPost->ID,'echo'=>false)).'"><span class="theme-post-navigation-label">'.esc_html__('Next:',THEME_DOMAIN).'</span><span class="theme-post-navigation-title">'.esc_html(get_the_title($nextPost->ID)).'</span></a>';		
		}
			
		if($Validation->isNotEmpty($html))
		{
			$class=array('theme-post-navigation','theme-clear-fix');
					
			if($counter==1)
				array_push($class,'theme-post-navigation-single');
			
			$html=
			'
				<div'.ThemeHelper::createClassAttribute($class).'>
					'.$html.'
				</div>				
			';
		}	
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createPostRelated()
	{
		global $post,$norge_functionCreatePostReleated;
		
		$norge_functionCreatePostReleated=1;
		
		$html=null;
		
		$Layout=new ThemeLayout();
		$Validation=new ThemeValidation();

		$parameter=array
		(
			'post_type'				=>	'post',
			'posts_per_page'		=>	3,
			'post__not_in'			=>	array(get_the_ID()),
			'orderby'				=>	'date',
			'order'					=>	'desc',
			'meta_query'			=>	array(array('key'=>'_thumbnail_id')),
			'tag__in'				=>	wp_get_post_tags(get_the_ID(),array('fields'=>'ids'))
		);

		$query=new WP_Query($parameter);

		if(!$query) return($html);
		if(!count($query->posts)) return($html);
		
		$i=0;
		global $post;
		$bPost=$post;

		while($query->have_posts())
		{
			$query->the_post();

			if(!has_post_thumbnail()) continue;

			/***/

			$metaBoxTopHtml=null;

			if(ThemeOption::getGlobalOption($post,'post_date_visible'))
				$metaBoxTopHtml='<div class="theme-post-related-date"><a href="'.esc_url(get_month_link(get_the_time('Y'),get_the_time('m'))).'" title="'.sprintf(esc_attr__('View all posts from "%s %s".',THEME_DOMAIN),get_the_time('F'),get_the_time('Y')).'">'.esc_html(get_the_date()).'</a></div>';	
			if($Validation->isNotEmpty($metaBoxTopHtml))
				$metaBoxTopHtml='<div class="theme-post-related-meta-box-top">'.$metaBoxTopHtml.'</div>';				

			/***/

			$metaBoxBottomHtml=null;

			if(ThemeOption::getGlobalOption($post,'post_view_count_visible'))
				$metaBoxBottomHtml.=$this->createPostViewCountCircle($post,'small');
			if(ThemeOption::getGlobalOption($post,'post_comment_count_visible'))
				$metaBoxBottomHtml.=$this->createPostCommentCountCircle($post,'small');
			if(ThemeOption::getGlobalOption($post,'post_like_count_visible'))
				$metaBoxBottomHtml.=$this->createPostLikeCountCircle($post,'small');

			if($Validation->isNotEmpty($metaBoxBottomHtml))
				$metaBoxBottomHtml='<div class="theme-post-related-meta-box-bottom">'.$metaBoxBottomHtml.'</div>';

			/***/

			$class=array
			(
				array
				(
					$Layout->getLayoutColumnCSSClass('33x33x33',$i)
				),
				array
				(
					'pb-image-box',
					'pb-image-hover',
					'pb-image-hover-type-fade'
				)
			);

			if(ThemeHelper::isPluginActive('page-builder'))
				array_push($class[1],'pb-image-preloader','pb-image-preloader-animation-enable');
			
			$html.=
			'
				<li'.ThemeHelper::createClassAttribute($class[0]).'>
					<div'.ThemeHelper::createClassAttribute($class[1]).'>
						<a href="'.esc_url(get_the_permalink()).'" class="pb-image" title="'.the_title_attribute(array('echo'=>false)).'">
							'.get_the_post_thumbnail(get_the_ID(),'image-640').'
							<span><span><span></span></span></span>
						</a>
					</div>		
					'.$metaBoxTopHtml.'
					<h5 class="theme-post-related-header"><a href="'.esc_url(get_the_permalink()).'" title="'.the_title_attribute(array('echo'=>false)).'">'.esc_html(get_the_title()).'</a></h5>
					<div class="theme-post-related-excerpt">'.apply_filters('the_excerpt',get_the_excerpt()).'</div>
					'.$metaBoxBottomHtml.'
				</li>
			';

			$i++;

			/***/
		}

		$post=$bPost;

		$class=array('theme-reset-list','theme-clear-fix','theme-layout-33x33x33');

		$html=
		'
			<div class="theme-post-related theme-clear-fix">
				<h4 class="aligncenter">
					<span>'.esc_html__('Related stories',THEME_DOMAIN).'</span>
					<span class="pb-header-underline aligncenter"></span>
				</h4>
				<ul'.ThemeHelper::createClassAttribute($class).'>
					'.$html.'
				</ul>
			</div>
		';
		
		$norge_functionCreatePostReleated=0;
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createPostCountCircleLabel($value,$label)
	{
		$title=null;
		
		if($value==0) $title=$label[0];
		elseif($value==1) $title=$label[1];		
		else $title=sprintf($label[2],$value);		
		
		return($title);
	}
	
	/**************************************************************************/
	
	function createPostViewCountCircle($post,$circleSize='medium')
	{
		$viewCount=$this->getPostViewCount($post->ID);
						
		$title=$this->createPostCountCircleLabel($viewCount,array
		(
			esc_attr__('This post has no views.',THEME_DOMAIN),
			esc_attr__('This post has 1 view.',THEME_DOMAIN),
			esc_attr__('This post has %s views.',THEME_DOMAIN)
		));
		
		$html=
		'				
			<span class="theme-circle theme-circle-size-'.$circleSize.'">
				<span class="theme-circle-top fa fa-eye">
					<a href="'.esc_url(get_the_permalink($post->ID)).'" title="'.$title.'"></a>
				</span>
				<span class="theme-circle-bottom">'.$viewCount.'</span>
			</span>	
		';
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createPostLikeCountCircle($post,$circleSize='medium')
	{
		$likeCount=$this->getPostLikeCount($post->ID);
		
		$title=$this->createPostCountCircleLabel($likeCount,array
		(
			esc_attr__('This post has no likes.',THEME_DOMAIN),
			esc_attr__('This post has 1 like.',THEME_DOMAIN),
			esc_attr__('This post has %s likes.',THEME_DOMAIN)
		));
		
		$html=
		'
			<span class="theme-circle theme-circle-size-'.esc_attr($circleSize).'">
				<span class="theme-circle-top'.($this->isPostLikeInSession($post->ID) ? ' theme-status-selected' : null).' fa fa-heart">
					<a href="#" class="theme-set-post-like-count theme-value-post-id-'.$post->ID.'" title="'.$title.'"></a>
				</span>
				<span class="theme-circle-bottom">'.$likeCount.'</span>
			</span>	
		';
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createPostCommentCountCircle($post,$circleSize='medium')
	{
		$commentCount=(int)get_comments_number($post->ID);
		
		$title=$this->createPostCountCircleLabel($commentCount,array
		(
			esc_attr__('This post has no comments.',THEME_DOMAIN),
			esc_attr__('This post has 1 comment.',THEME_DOMAIN),
			esc_attr__('This post has %s comments.',THEME_DOMAIN)
		));
		
		$html=
		'				
			<span class="theme-circle theme-circle-size-'.esc_attr($circleSize).'">
				<span class="theme-circle-top fa fa-comment">
					<a href="'.esc_url(get_the_permalink($post->ID)).'#comments" title="'.$title.'" class="theme-scroll-to-comment"></a>
				</span>
				<span class="theme-circle-bottom">'.$commentCount.'</span>
			</span>
		';
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createPostShareCircle($post,$circleSize='medium')
	{
		$shareHTML=null;
		
		$title=get_the_title($post->ID);
		$url=get_the_permalink($post->ID);
		
		$twitterStatus=mb_substr($title,0,139-mb_strlen($url)).' '.$url;
		
		$shareHTML.=
		'
			<span>
				<a href="https://twitter.com/home?status='.urlencode($twitterStatus).'" title="'.esc_html__('Share on Twitter',THEME_DOMAIN).'" class="pb-window-target-blank">
					<span class="theme-circle theme-circle-size-small">
						<span class="theme-circle-top fa fa-twitter">
						</span>
					</span>						
					<span class="theme-post-share-label">'.esc_html__('Twitter',THEME_DOMAIN).'</span>
				</a>
			</span>		
		';
		
		if(has_post_thumbnail($post->ID))
		{
			$shareHTML.=
			'
				<span>
					<a href="https://pinterest.com/pin/create/button/?url='.esc_url(get_the_permalink($post->ID)).'&amp;media='.esc_url(wp_get_attachment_url(get_post_thumbnail_id($post->ID))).'&amp;description='.urlencode(strip_tags(ThemeHelper::getTheExcerpt($post->ID))).'" title="'.esc_attr__('Share on Pinterest',THEME_DOMAIN).'" class="pb-window-target-blank">
						<span class="theme-circle theme-circle-size-small">
							<span class="theme-circle-top fa fa-pinterest">
							</span>
						</span>						
						<span class="theme-post-share-label">'.esc_html__('Pinterest',THEME_DOMAIN).'</span>
					</a>
				</span>				
			';
		}
		
		$shareHTML.=
		'
			<span>
				<a href="https://www.facebook.com/sharer/sharer.php?u='.esc_url(get_the_permalink($post->ID)).'" title="'.esc_attr__('Share on Facebook',THEME_DOMAIN).'" class="pb-window-target-blank">
					<span class="theme-circle theme-circle-size-small">
						<span class="theme-circle-top fa fa-facebook"></span>
					</span>						
					<span class="theme-post-share-label">'.esc_html__('Facebook',THEME_DOMAIN).'</span>
				</a>
			</span>				
		';
		
		$html=
		'
			<span class="theme-circle theme-circle-size-'.esc_attr($circleSize).'">
				<span class="theme-circle-top fa fa-share-alt">
					<a href="#" class="theme-set-post-share theme-value-post-id-'.$post->ID.'" title="'.esc_attr__('Click to share this post.',THEME_DOMAIN).'"></a>
				</span>
				<span class="theme-circle-bottom">'.esc_html__('Share',THEME_DOMAIN).'</span>
				<span class="theme-post-share theme-status-close" id="theme-post-share">
					<span>
						'.$shareHTML.'
					</span>
				</span>					
			</span>	
		';
		
		return($html);
	}
	
	/**************************************************************************/
	
	function createFeatureElement($post,$option,$widgetAreaData)
	{
		$html=null;
		$shortcode=null;
		
		$Page=new ThemePage();
		$Validation=new ThemeValidation();
		
		if((!ThemeHelper::isPluginActive('page-builder')) && (in_array(get_post_format(),array('audio','gallery','video')))) return($html);
		
		switch(get_post_format())
		{
			case 'audio':
						
				$shortcode=
				'
					[pb_audio]
					[pb_audio_track]
					[pb_audio_track_item format_mp3="'.$option['post_post_format_audio_track_url_mp3'].'" format_ogg="'.$option['post_post_format_audio_track_url_ogg'].'"]
					[pb_audio_track_item_artist]'.$option['post_post_format_audio_artist'].'[/pb_audio_track_item_artist]
					[pb_audio_track_item_title]'.$option['post_post_format_audio_track_title'].'[/pb_audio_track_item_title]
					[/pb_audio_track_item]
					[/pb_audio_track]
					[/pb_audio]	
				';
						
			break;
				
			case 'video':
				
				$shortcode='[pb_video type="'.$option['post_post_format_video_type'].'" src="'.$option['post_post_format_video_url'].'"][/pb_video]';

			break;
				
			case 'gallery':
						
				$shortcode='[pb_nivo_slider image="'.$option['post_post_format_gallery_file_id'].'" image_size="'.$Page->getImageClass($widgetAreaData['location']).'" url="'.get_the_permalink().'" transition_effect="fade" preloader_enable="1" direction_navigation_enable="1" control_navigation_enable="0" control_navigation_thumbs_enable="0" manual_advance_enable="1"][/pb_nivo_slider]';
				
			break;
					
			default:
						
				if(has_post_thumbnail())
				{
					$class=array('pb-image-box');
					
					if(ThemeHelper::isPluginActive('page-builder'))
						array_push($class,'pb-image-preloader','pb-image-preloader-animation-enable');
					
					if(is_single()) 
					{
						list($link)=wp_get_attachment_image_src(get_post_thumbnail_id(),'full');
						array_push($class,'pb-image-type-image');
					}
					else $link=get_the_permalink();
					
					$html=
					'
						<div'.ThemeHelper::createClassAttribute($class).'>
							<a href="'.esc_url($link).'" class="pb-image" title="'.esc_attr(get_the_title($post->ID)).'">
								'.get_the_post_thumbnail(get_the_ID(),$Page->getImageClass($widgetAreaData['location'])).'
							</a>
						</div>						
					';
				}
		}
		
		if($Validation->isNotEmpty($shortcode))
			$html=do_shortcode($shortcode);
		
		if($Validation->isNotEmpty($html))
			$html='<div class="theme-post-feature">'.$html.'</div>';
						
		return($html);				
	}
	
	/**************************************************************************/
	
	function setPostLikeCount()
	{
		$postId=(int)$_GET['post_id'];
		
		$response=array('post_id'=>$postId,'like_count'=>-1);
				
		if(get_post_status($postId)===false)
		{
			echo json_encode($response);
			die();
		}
				
		$cookiePostId=array();
		if(array_key_exists(THEME_COOKIE_NAME_POST_LIKE_COUNT,$_COOKIE))
			$cookiePostId=array_map('intval',preg_split('/\./',$_COOKIE[THEME_COOKIE_NAME_POST_LIKE_COUNT]));
		
		if(in_array($postId,$cookiePostId))
		{
			echo json_encode($response);
			die();			
		}
		
		array_push($cookiePostId,$postId);
		
		$url=parse_url(get_site_url());

		setcookie(THEME_COOKIE_NAME_POST_LIKE_COUNT,join('.',$cookiePostId),0,$url['path']);
		
		$likeCount=$this->getPostLikeCount($postId)+1;
		
		update_post_meta($postId,THEME_COOKIE_NAME_POST_LIKE_COUNT,$likeCount);
		
		$response['like_count']=$likeCount;
		
		$response['title']=$this->createPostCountCircleLabel($likeCount,array
		(
			esc_attr__('This post has no likes.',THEME_DOMAIN),
			esc_attr__('This post has 1 like.',THEME_DOMAIN),
			esc_attr__('This post has %s likes.',THEME_DOMAIN)
		));
		
		echo json_encode($response);
		die();			
	}
	
	/**************************************************************************/
	
	function getPostLikeCount($postId)
	{
		return((int)get_post_meta($postId,THEME_COOKIE_NAME_POST_LIKE_COUNT,true));	
	}
	
	/**************************************************************************/
	
	function isPostLikeInSession($postId)
	{		
		$cookiePostId=array();
		if(array_key_exists(THEME_COOKIE_NAME_POST_LIKE_COUNT,$_COOKIE))
			$cookiePostId=array_map('intval',preg_split('/\./',$_COOKIE[THEME_COOKIE_NAME_POST_LIKE_COUNT]));		
	
		return((in_array($postId,$cookiePostId)));
	}
	
	/**************************************************************************/
	
	function setPostViewCount()
	{
		global $post;
				
		$cookiePostId=array();
		if(array_key_exists(THEME_COOKIE_NAME_POST_VIEW_COUNT,$_COOKIE))
			$cookiePostId=array_map('intval',explode('\.',$_COOKIE[THEME_COOKIE_NAME_POST_VIEW_COUNT]));
		
		if(in_array($post->ID,$cookiePostId)) return;
		
		array_push($cookiePostId,$post->ID);
		
		$url=parse_url(get_site_url());

		setcookie(THEME_COOKIE_NAME_POST_VIEW_COUNT,join('.',$cookiePostId),0,$url['path']);
		
		update_post_meta($post->ID,THEME_COOKIE_NAME_POST_VIEW_COUNT,$this->getPostViewCount($post->ID)+1);
	}
	
	/**************************************************************************/
	
	function getPostViewCount($postId)
	{
		return((int)get_post_meta($postId,THEME_COOKIE_NAME_POST_VIEW_COUNT,true));
	}
		
	/**************************************************************************/
	
	function getPostMostComment($argument)
	{
		$parameter=array
		(
			'post_type'							=>	'post',
			'posts_per_page'					=>	(int)$argument['post_count'],
			'orderby'							=>	'comment_count',
			'order'								=>	'desc'
		);
		
		$query=new WP_Query($parameter);
		return($query);
	}
	
	/**************************************************************************/
	
	function getPostMostLike($argument)
	{
		$parameter=array
		(
			'post_type'							=>	'post',
			'posts_per_page'					=>	(int)$argument['post_count'],
			'meta_key'							=>	THEME_COOKIE_NAME_POST_LIKE_COUNT,
			'orderby'							=>	'meta_value_num',
			'order'								=>	'desc'
		);
		
		$query=new WP_Query($parameter);
		return($query);		
	}
	
	/**************************************************************************/
	
	function getPostRecent($argument)
	{
		$parameter=array
		(
			'post_type'							=>	'post',
			'posts_per_page'					=>	(int)$argument['post_count'],
			'orderby'							=>	'date',
			'order'								=>	'desc'
		);

		$query=new WP_Query($parameter);
		return($query);
	}
	
	/**************************************************************************/
	
	function isPasswordProtected($post)
	{
		if(is_single())
			return(post_password_required($post));
		
		return(false);
	}
	
	/**************************************************************************/
	
	function setPostMetaDefault(&$meta,$part='all')
	{
		if(in_array($part,array('post','all')))
		{
			ThemeHelper::setDefaultOption($meta,'post_date_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_tag_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_category_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_author_name_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_author_info_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_like_count_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_view_count_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_comment_count_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_navigation_visible',-1);
			ThemeHelper::setDefaultOption($meta,'post_share_button_visible',-1);	
			ThemeHelper::setDefaultOption($meta,'post_post_related_visible',-1);	
		}
		
		if(in_array($part,array('post_audio','all')))
		{
			ThemeHelper::setDefaultOption($meta,'post_post_format_audio_artist','');
			ThemeHelper::setDefaultOption($meta,'post_post_format_audio_track_title','');
			ThemeHelper::setDefaultOption($meta,'post_post_format_audio_track_url_mp3','');
			ThemeHelper::setDefaultOption($meta,'post_post_format_audio_track_url_ogg','');
		}
		
		if(in_array($part,array('post_video','all')))
		{		
			ThemeHelper::setDefaultOption($meta,'post_post_format_video_url','');
			ThemeHelper::setDefaultOption($meta,'post_post_format_video_type','youtube');
		}
		
		if(in_array($part,array('post_gallery','all')))
		{
			ThemeHelper::setDefaultOption($meta,'post_post_format_gallery_file_id','');
		}
	}
	
	/**************************************************************************/
}

/******************************************************************************/
/******************************************************************************/